@@ -9,10 +9,12 @@ from outflow.core.command import RootCommand
 
 ROOT_DIRECTORY = os.environ.get("PIPELINE_ROOT_DIRECTORY", None)
 
-MAIN_DATABASE = "MAIN-DB"
+MAIN_DATABASE = "default"
 
 PLUGINS = [
     "outflow.management",
 ]
 
+BACKENDS = {"ray": "outflow.ray.backend"}
+
 ROOT_COMMAND_CLASS = RootCommand
